import React, { useState } from 'react';
import { View, Text, TouchableOpacity, FlatList } from 'react-native';
import { Ionicons } from '@expo/vector-icons';
import { FrenchFlagIcon, EnglishFlagIcon, PortugueseFlagIcon, SpanishFlagIcon } from './flags';

interface Country {
  flag: string;
  name: string;
}

interface Props {
  countries: Country[];
  defaultCountry: string;
}

const flags = {
  'France': <FrenchFlagIcon />,
  'United Kingdom': <EnglishFlagIcon />,
  'Portugal': <PortugueseFlagIcon />,
  'Spain': <SpanishFlagIcon />,
};

const CountryFlagSelect: React.FC<Props> = ({ countries, defaultCountry }) => {
  const [selectedCountry, setSelectedCountry] = useState(defaultCountry);
  const [showList, setShowList] = useState(false);

  const handleCountrySelect = (country: string) => {
    setSelectedCountry(country);
    setShowList(false);
  };

  const renderCountryItem = ({ item }: { item: Country }) => (
    <TouchableOpacity onPress={() => handleCountrySelect(item.name)}>
      <View style={{ flexDirection: 'row', alignItems: 'center', paddingVertical: 8 }}>
        {flags[item.name]}
        <Text style={{ fontSize: 16, marginLeft: 8 }}>{item.name}</Text>
      </View>
    </TouchableOpacity>
  );

  return (
    <View>
      <TouchableOpacity onPress={() => setShowList(!showList)} style={{ flexDirection: 'row', alignItems: 'center' }}>
        {showList ? (
          <Ionicons name="chevron-up" size={24} color="black" />
        ) : (
          <Ionicons name="chevron-down" size={24} color="black" />
        )}
        {flags[selectedCountry]} 
      </TouchableOpacity>
      {showList && (
        <FlatList
          data={countries}
          renderItem={renderCountryItem}
          keyExtractor={(item) => item.name}
          style={{ maxHeight: 200 }}
        />
      )}
    </View>
  );
};

export default CountryFlagSelect;
